@@ -1,2 +1,2 @@
-import BasicTest
+import Lib
 main = basicTest $ defaultConfig { massage = "Basic Test Version 3.0" }
