@@ -3,22 +3,15 @@
 # Tests Dyre's ability to recompile a custom configuration
 # upon relaunch, and restore the state again after.
 
-# Assert the equality of two strings.
-function assert() {
-    echo "$1" >&2
-    if [ "$1" != "$2" ]; then
-        echo "Failed test $3";
-        exit 1;
-    fi
-}
+. ../subr.sh
 
-mkdir working
+mkdir -p working
 cd working
 
 ### TEST A ###
-cp ../ConfigCheckTest.hs ../Main.hs .
+cp ../Lib.hs ../Main.hs .
 cp ../configCheckTestA.hs ./configCheckTest.hs
-ghc --make Main.hs -o configCheck 2> /dev/null
+$HC --make Main.hs -o configCheck || die "compilation failed"
 OUTPUT_A=`./configCheck --dyre-debug`
 assert "$OUTPUT_A" "custom-a" "A"
 
